package cn.com.infosec.x509.examples;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.misc.MiscObjectIdentifiers;
import cn.com.infosec.asn1.misc.NetscapeCertType;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.jce.provider.InfosecProvider;
import cn.com.infosec.x509.AttributeCertificateHolder;
import cn.com.infosec.x509.AttributeCertificateIssuer;
import cn.com.infosec.x509.X509Attribute;
import cn.com.infosec.x509.X509V1CertificateGenerator;
import cn.com.infosec.x509.X509V2AttributeCertificate;
import cn.com.infosec.x509.X509V2AttributeCertificateGenerator;
import cn.com.infosec.x509.X509V3CertificateGenerator;
import java.math.BigInteger;
import java.security.KeyFactory;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.Security;
import java.security.cert.X509Certificate;
import java.security.spec.RSAPrivateCrtKeySpec;
import java.security.spec.RSAPublicKeySpec;
import java.util.Date;
import java.util.Hashtable;
import java.util.Vector;

public class AttrCertExample {
   static X509V1CertificateGenerator v1CertGen = new X509V1CertificateGenerator();
   static X509V3CertificateGenerator v3CertGen = new X509V3CertificateGenerator();

   public static X509Certificate createAcIssuerCert(PublicKey pubKey, PrivateKey privKey) {
      v1CertGen.setSerialNumber(BigInteger.valueOf(10L));
      v1CertGen.setIssuerDN(new X509Principal("C=AU, O=The Legion of the Bouncy Castle, OU=Bouncy Primary Certificate"));
      v1CertGen.setNotBefore(new Date(System.currentTimeMillis() - 2592000000L));
      v1CertGen.setNotAfter(new Date(System.currentTimeMillis() + 2592000000L));
      v1CertGen.setSubjectDN(new X509Principal("C=AU, O=The Legion of the Bouncy Castle, OU=Bouncy Primary Certificate"));
      v1CertGen.setPublicKey(pubKey);
      v1CertGen.setSignatureAlgorithm("SHA1WithRSAEncryption");
      X509Certificate var10000 = v1CertGen.generateX509Certificate(privKey);
      var10000.checkValidity(new Date());
      var10000.verify(pubKey);
      return var10000;
   }

   public static X509Certificate createClientCert(PublicKey pubKey, PrivateKey caPrivKey, PublicKey caPubKey) {
      Hashtable var3;
      var3 = new Hashtable.<init>();
      Vector var4;
      Vector var10000 = var4 = new Vector;
      var4.<init>();
      DERObjectIdentifier var5;
      var3.put(var5 = X509Name.C, "AU");
      DERObjectIdentifier var6;
      var3.put(var6 = X509Name.O, "The Legion of the Bouncy Castle");
      DERObjectIdentifier var7;
      var3.put(var7 = X509Name.L, "Melbourne");
      DERObjectIdentifier var8;
      var3.put(var8 = X509Name.CN, "Eric H. Echidna");
      DERObjectIdentifier var9;
      var3.put(var9 = X509Name.EmailAddress, "feedback-crypto@Infosec.org");
      var10000.addElement(var5);
      var10000.addElement(var6);
      var10000.addElement(var7);
      var10000.addElement(var8);
      var10000.addElement(var9);
      v3CertGen.reset();
      v3CertGen.setSerialNumber(BigInteger.valueOf(20L));
      v3CertGen.setIssuerDN(new X509Principal("C=AU, O=The Legion of the Bouncy Castle, OU=Bouncy Primary Certificate"));
      v3CertGen.setNotBefore(new Date(System.currentTimeMillis() - 2592000000L));
      v3CertGen.setNotAfter(new Date(System.currentTimeMillis() + 2592000000L));
      v3CertGen.setSubjectDN(new X509Principal(var4, var3));
      v3CertGen.setPublicKey(pubKey);
      v3CertGen.setSignatureAlgorithm("SHA1WithRSAEncryption");
      X509V3CertificateGenerator var11 = v3CertGen;
      DERObjectIdentifier var10001 = MiscObjectIdentifiers.netscapeCertType;
      NetscapeCertType pubKey1;
      pubKey1 = new NetscapeCertType.<init>(48);
      var11.addExtension(var10001, false, pubKey1);
      X509Certificate var12 = v3CertGen.generateX509Certificate(caPrivKey);
      var12.checkValidity(new Date());
      var12.verify(caPubKey);
      return var12;
   }

   public static void main(String[] args) {
      Security.addProvider(new InfosecProvider());
      RSAPublicKeySpec args1;
      RSAPublicKeySpec var10000 = args1 = new RSAPublicKeySpec;
      BigInteger var10001 = new BigInteger("b4a7e46170574f16a97082b22be58b6a2a629798419be12872a4bdba626cfae9900f76abfb12139dce5de56564fab2b6543165a040c606887420e33d91ed7ed7", 16);
      BigInteger var1;
      var1 = new BigInteger.<init>("11", 16);
      var10000.<init>(var10001, var1);
      RSAPrivateCrtKeySpec var16;
      RSAPrivateCrtKeySpec var31 = var16 = new RSAPrivateCrtKeySpec;
      var10001 = new BigInteger("b4a7e46170574f16a97082b22be58b6a2a629798419be12872a4bdba626cfae9900f76abfb12139dce5de56564fab2b6543165a040c606887420e33d91ed7ed7", 16);
      BigInteger var2;
      var2 = new BigInteger.<init>("11", 16);
      BigInteger var3;
      var3 = new BigInteger.<init>("9f66f6b05410cd503b2709e88115d55daced94d1a34d4e32bf824d0dde6028ae79c5f07b580f5dce240d7111f7ddb130a7945cd7d957d1920994da389f490c89", 16);
      BigInteger var4;
      var4 = new BigInteger.<init>("c0a0758cdf14256f78d4708c86becdead1b50ad4ad6c5c703e2168fbf37884cb", 16);
      BigInteger var5;
      var5 = new BigInteger.<init>("f01734d7960ea60070f1b06f2bb81bfac48ff192ae18451d5e56c734a5aab8a5", 16);
      BigInteger var6;
      var6 = new BigInteger.<init>("b54bb9edff22051d9ee60f9351a48591b6500a319429c069a3e335a1d6171391", 16);
      BigInteger var7;
      var7 = new BigInteger.<init>("d3d83daf2a0cecd3367ae6f8ae1aeb82e9ac2f816c6fc483533d8297dd7884cd", 16);
      BigInteger var8;
      var8 = new BigInteger.<init>("b8f52fc6f38593dabb661d3f50f8897f8106eee68b1bce78a95b132b4e5b5d19", 16);
      var31.<init>(var10001, var2, var3, var4, var5, var6, var7, var8);
      RSAPublicKeySpec var22;
      var10000 = var22 = new RSAPublicKeySpec;
      var10001 = new BigInteger("b259d2d6e627a768c94be36164c2d9fc79d97aab9253140e5bf17751197731d6f7540d2509e7b9ffee0a70a6e26d56e92d2edd7f85aba85600b69089f35f6bdbf3c298e05842535d9f064e6b0391cb7d306e0a2d20c4dfb4e7b49a9640bdea26c10ad69c3f05007ce2513cee44cfe01998e62b6c3637d3fc0391079b26ee36d5", 16);
      var3 = new BigInteger.<init>("11", 16);
      var10000.<init>(var10001, var3);
      RSAPrivateCrtKeySpec var25;
      var31 = var25 = new RSAPrivateCrtKeySpec;
      var10001 = new BigInteger("b259d2d6e627a768c94be36164c2d9fc79d97aab9253140e5bf17751197731d6f7540d2509e7b9ffee0a70a6e26d56e92d2edd7f85aba85600b69089f35f6bdbf3c298e05842535d9f064e6b0391cb7d306e0a2d20c4dfb4e7b49a9640bdea26c10ad69c3f05007ce2513cee44cfe01998e62b6c3637d3fc0391079b26ee36d5", 16);
      var4 = new BigInteger.<init>("11", 16);
      var5 = new BigInteger.<init>("92e08f83cc9920746989ca5034dcb384a094fb9c5a6288fcc4304424ab8f56388f72652d8fafc65a4b9020896f2cde297080f2a540e7b7ce5af0b3446e1258d1dd7f245cf54124b4c6e17da21b90a0ebd22605e6f45c9f136d7a13eaac1c0f7487de8bd6d924972408ebb58af71e76fd7b012a8d0e165f3ae2e5077a8648e619", 16);
      var6 = new BigInteger.<init>("f75e80839b9b9379f1cf1128f321639757dba514642c206bbbd99f9a4846208b3e93fbbe5e0527cc59b1d4b929d9555853004c7c8b30ee6a213c3d1bb7415d03", 16);
      var7 = new BigInteger.<init>("b892d9ebdbfc37e397256dd8a5d3123534d1f03726284743ddc6be3a709edb696fc40c7d902ed804c6eee730eee3d5b20bf6bd8d87a296813c87d3b3cc9d7947", 16);
      var8 = new BigInteger.<init>("1d1a2d3ca8e52068b3094d501c9a842fec37f54db16e9a67070a8b3f53cc03d4257ad252a1a640eadd603724d7bf3737914b544ae332eedf4f34436cac25ceb5", 16);
      BigInteger var9;
      var9 = new BigInteger.<init>("6c929e4e81672fef49d9c825163fec97c4b7ba7acb26c0824638ac22605d7201c94625770984f78a56e6e25904fe7db407099cad9b14588841b94f5ab498dded", 16);
      BigInteger var10;
      var10 = new BigInteger.<init>("dae7651ee69ad1d081ec5e7188ae126f6004ff39556bde90e0b870962fa7b926d070686d8244fe5a9aa709a95686a104614834b0ada4b10f53197a5cb4c97339", 16);
      var31.<init>(var10001, var4, var5, var6, var7, var8, var9, var10);
      KeyFactory var28;
      KeyFactory var32 = var28 = KeyFactory.getInstance("RSA", "INFOSEC");
      PrivateKey args2 = var28.generatePrivate(var25);
      PublicKey var18 = var28.generatePublic(var22);
      var28.generatePrivate(var16);
      PublicKey var33 = var32.generatePublic(args1);
      X509Certificate var23 = createAcIssuerCert(var18, args2);
      X509Certificate var26 = createClientCert(var33, args2, var18);
      X509V2AttributeCertificateGenerator var34 = new X509V2AttributeCertificateGenerator();
      var34.reset();
      var34.setHolder(new AttributeCertificateHolder(var26));
      var34.setIssuer(new AttributeCertificateIssuer(var23.getSubjectX500Principal()));
      var34.setSerialNumber(new BigInteger("1"));
      var34.setNotBefore(new Date(System.currentTimeMillis() - 50000L));
      var34.setNotAfter(new Date(System.currentTimeMillis() + 50000L));
      var34.setSignatureAlgorithm("SHA1WithRSAEncryption");
      GeneralName args3;
      args3 = new GeneralName.<init>(1, "DAU123456789");
      ASN1EncodableVector var29;
      ASN1EncodableVector var40 = var29 = new ASN1EncodableVector;
      var29.<init>();
      var40.add(args3);
      DERSequence args4;
      args4 = new DERSequence.<init>(var29);
      var34.addAttribute(new X509Attribute("2.5.24.72", args4));
      X509V2AttributeCertificate args5;
      AttributeCertificateHolder var30;
      if ((var30 = (args5 = (X509V2AttributeCertificate)var34.generateCertificate(args2, "INFOSEC")).getHolder()).match(var26)) {
         if (var30.getEntityNames() != null) {
            System.out.println(var30.getEntityNames().length + " entity names found");
         }

         if (var30.getIssuer() != null) {
            System.out.println(var30.getIssuer().length + " issuer names found, serial number " + var30.getSerialNumber());
         }

         System.out.println("Matches original client x509 cert");
      }

      AttributeCertificateIssuer var27;
      if ((var27 = args5.getIssuer()).match(var23)) {
         if (var27.getPrincipals() != null) {
            System.out.println(var27.getPrincipals().length + " entity names found");
         }

         System.out.println("Matches original ca x509 cert");
      }

      X509V2AttributeCertificate var36 = args5;
      X509V2AttributeCertificate var39 = args5;
      System.out.println("valid not before: " + args5.getNotBefore());
      System.out.println("valid not before: " + args5.getNotAfter());

      try {
         var39.checkValidity();
         var36.checkValidity(new Date());
      } catch (Exception var12) {
         System.out.println(var12);
      }

      try {
         args5.verify(var18, "INFOSEC");
      } catch (Exception var11) {
         System.out.println(var11);
      }

      X509Attribute[] args6 = args5.getAttributes();
      System.out.println("cert has " + args6.length + " attributes:");

      for(int var21 = 0; var21 < args6.length; ++var21) {
         X509Attribute var24;
         X509Attribute var38 = var24 = args6[var21];
         System.out.println("OID: " + var24.getOID());
         if (var38.getOID().equals("2.5.24.72")) {
            System.out.println("rolesyntax read from cert!");
         }
      }

   }
}
